==> haskell-appar-0.1.8-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-appar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 appar
version:              0.1.8
visibility:           public
id:                   appar-0.1.8-BUPUPrByh26HKIMqqPxdXI
key:                  appar-0.1.8-BUPUPrByh26HKIMqqPxdXI
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             A simple applicative parser
description:          A simple applicative parser in Parsec style
category:             Parsing
abi:                  3d1e57e8938cdef148425ce422617cac
exposed:              True
exposed-modules:
    Text.Appar.ByteString Text.Appar.LazyByteString Text.Appar.String

hidden-modules:       Text.Appar.Input Text.Appar.Parser
import-dirs:          /usr/lib/ghc-8.8.1/site-local/appar-0.1.8
library-dirs:         /usr/lib/ghc-8.8.1/site-local/appar-0.1.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/appar-0.1.8
hs-libraries:         HSappar-0.1.8-BUPUPrByh26HKIMqqPxdXI
depends:              base-4.13.0.0 bytestring-0.10.9.0
haddock-interfaces:   /usr/share/doc/haskell-appar/html/appar.haddock
haddock-html:         /usr/share/doc/haskell-appar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-appar-0.1.8-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-appar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 appar
version:              0.1.8
visibility:           public
id:                   appar-0.1.8-Ivne98HYrwb7S9Jxqgw6mR
key:                  appar-0.1.8-Ivne98HYrwb7S9Jxqgw6mR
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             A simple applicative parser
description:          A simple applicative parser in Parsec style
category:             Parsing
abi:                  843c06c9c57920c5048bc71cfc5e9d5c
exposed:              True
exposed-modules:
    Text.Appar.ByteString Text.Appar.LazyByteString Text.Appar.String

hidden-modules:       Text.Appar.Input Text.Appar.Parser
import-dirs:          /usr/lib/ghc-8.8.2/site-local/appar-0.1.8
library-dirs:         /usr/lib/ghc-8.8.2/site-local/appar-0.1.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.2/appar-0.1.8
hs-libraries:         HSappar-0.1.8-Ivne98HYrwb7S9Jxqgw6mR
depends:              base-4.13.0.0 bytestring-0.10.10.0
haddock-interfaces:   /usr/share/doc/haskell-appar/html/appar.haddock
haddock-html:         /usr/share/doc/haskell-appar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
